.callout.svelte-y8yhe6{border-radius:var(--radius-xl, 16px);padding:.75rem 1rem;border:1px solid transparent;color:var(--color-text-secondary, #3c3a36)}.callout-header.svelte-y8yhe6{display:flex;justify-content:space-between;align-items:center;font-weight:600;cursor:default;background:transparent;border:none;width:100%;text-align:left;padding:0;font-size:inherit;color:inherit}button.callout-header.svelte-y8yhe6{cursor:pointer}.callout-body.svelte-y8yhe6{margin-top:.5rem}.callout.info.svelte-y8yhe6{background:var(--color-pill-subtle-bg, #eef5f3);border-color:var(--color-border, #f0ebe4)}.callout.warning.svelte-y8yhe6{background:var(--color-pill-ghost-bg, #f4f0ea);border-color:var(--color-border, #f0ebe4)}.callout.error.svelte-y8yhe6{background:var(--color-error-bg, #fdf3f3);border-color:var(--color-error-border, #f5dddd);color:var(--color-error-text, #9b2d2d)}.callout.success.svelte-y8yhe6{background:var(--color-pill-subtle-bg, #eef5f3);border-color:var(--color-border, #f0ebe4)}.callout.tip.svelte-y8yhe6{background:var(--color-tab-active-bg, #e8f6f2);border-color:var(--color-border, #f0ebe4)}.callout.note.svelte-y8yhe6{background:var(--color-code-bg, #fbf8f3);border-color:var(--color-border, #f0ebe4)}
