import{p as je,a as C,f as v,i,e as o,h as c,g as e,c as xe,j as F,t as p,F as ne,n as r,m as u,D as K,A as N,o as G,G as ie,r as ke,k as we}from"./index-BPc98LNf.js";import O from"./Markdown-BCaT_MOr.js";import"./purify.es-HRjpPm7y.js";import"./katex-XbL3y5x-.js";/* empty css                  */var Ce=v('<h1 class="svelte-djhbyc"> </h1>'),Re=v('<p class="subtitle svelte-djhbyc"> </p>'),Ae=v("<span> </span>"),Be=v("<span> </span>"),De=v("<span> </span>"),Ee=v('<div class="meta svelte-djhbyc"><!> <!> <!></div>'),Fe=v('<li class="svelte-djhbyc"><a class="svelte-djhbyc"> </a></li>'),Ge=v('<nav class="toc svelte-djhbyc"><h2 class="svelte-djhbyc">Contents</h2> <ul class="svelte-djhbyc"></ul></nav>'),Le=v('<h2 class="svelte-djhbyc"> </h2>'),Me=v('<figcaption class="svelte-djhbyc"> </figcaption>'),Te=v('<figure class="component-figure svelte-djhbyc"><!> <!></figure>'),qe=v('<h3 class="svelte-djhbyc"> </h3>'),ze=v('<figcaption class="svelte-djhbyc"> </figcaption>'),He=v('<figure class="component-figure svelte-djhbyc"><!> <!></figure>'),Ie=v('<section class="subsection svelte-djhbyc"><!> <!> <!></section>'),Je=v('<section class="svelte-djhbyc"><!> <!> <!> <!></section>'),Ke=v('<footer class="report-footer svelte-djhbyc"><!></footer>'),Ne=v('<article class="artifact-report svelte-djhbyc"><header class="report-header svelte-djhbyc"><!> <!> <!></header> <!> <div class="report-body svelte-djhbyc"></div> <!></article>');function Ve(le,j){je(j,!0);let P=C(j,"title",3,""),Q=C(j,"subtitle",3,""),g=C(j,"metadata",19,()=>({})),S=C(j,"toc",3,!1),U=C(j,"sections",19,()=>[]),V=C(j,"footer",3,"");function W(a){return a.toLowerCase().replace(/\s+/g,"-").replace(/[^\w-]/g,"")}function X(a,t=0){const s=[];for(const d of a)d.title&&s.push({title:d.title,id:d.id||W(d.title),level:t}),d.subsections&&s.push(...X(d.subsections,t+1));return s}const Y=xe(()=>S()?X(U()):[]);var Z=Ne(),$=o(Z),ee=o($);{var ce=a=>{var t=Ce(),s=o(t);p(()=>u(s,P())),r(a,t)};i(ee,a=>{P()&&a(ce)})}var te=c(ee,2);{var de=a=>{var t=Re(),s=o(t);p(()=>u(s,Q())),r(a,t)};i(te,a=>{Q()&&a(de)})}var _e=c(te,2);{var fe=a=>{var t=Ee(),s=o(t);{var d=l=>{var h=Ae(),k=o(h);p(()=>u(k,`By ${g().author??""}`)),r(l,h)};i(s,l=>{g().author&&l(d)})}var b=c(s,2);{var m=l=>{var h=Be(),k=o(h);p(()=>u(k,g().date)),r(l,h)};i(b,l=>{g().date&&l(m)})}var w=c(b,2);{var x=l=>{var h=De(),k=o(h);p(()=>u(k,`v${g().version??""}`)),r(l,h)};i(w,l=>{g().version&&l(x)})}r(a,t)};i(_e,a=>{(g().author||g().date)&&a(fe)})}var ae=c($,2);{var pe=a=>{var t=Ge(),s=c(o(t),2);F(s,21,()=>e(Y),G,(d,b)=>{var m=Fe();let w;var x=o(m),l=o(x);p(()=>{w=we(m,"",w,{"margin-left":`${e(b).level*1}rem`}),ne(x,"href",`#${e(b).id}`),u(l,e(b).title)}),r(d,m)}),r(a,t)};i(ae,a=>{S()&&e(Y).length>0&&a(pe)})}var re=c(ae,2);F(re,21,U,G,(a,t)=>{var s=Je(),d=o(s);{var b=n=>{var y=Le(),R=o(y);p(()=>u(R,e(t).title)),r(n,y)};i(d,n=>{e(t).title&&n(b)})}var m=c(d,2);{var w=n=>{O(n,{get content(){return e(t).content},padded:!1})};i(m,n=>{e(t).content&&n(w)})}var x=c(m,2);{var l=n=>{var y=K(),R=N(y);F(R,17,()=>e(t).components,G,(q,_)=>{var A=Te(),B=o(A);ie(B,{get component(){return e(_).component},get props(){return e(_).props}});var z=c(B,2);{var L=D=>{var M=Me(),H=o(M);p(()=>u(H,e(_).caption)),r(D,M)};i(z,D=>{e(_).caption&&D(L)})}r(q,A)}),r(n,y)};i(x,n=>{e(t).components&&n(l)})}var h=c(x,2);{var k=n=>{var y=K(),R=N(y);F(R,17,()=>e(t).subsections,G,(q,_)=>{var A=Ie(),B=o(A);{var z=f=>{var E=qe(),I=o(E);p(()=>u(I,e(_).title)),r(f,E)};i(B,f=>{e(_).title&&f(z)})}var L=c(B,2);{var D=f=>{O(f,{get content(){return e(_).content},padded:!1})};i(L,f=>{e(_).content&&f(D)})}var M=c(L,2);{var H=f=>{var E=K(),I=N(E);F(I,17,()=>e(_).components,G,(ge,T)=>{var oe=He(),se=o(oe);ie(se,{get component(){return e(T).component},get props(){return e(T).props}});var be=c(se,2);{var me=J=>{var ve=ze(),ye=o(ve);p(()=>u(ye,e(T).caption)),r(J,ve)};i(be,J=>{e(T).caption&&J(me)})}r(ge,oe)}),r(f,E)};i(M,f=>{e(_).components&&f(H)})}r(q,A)}),r(n,y)};i(h,n=>{e(t).subsections&&n(k)})}p(n=>ne(s,"id",n),[()=>e(t).id||(e(t).title?W(e(t).title):void 0)]),r(a,s)});var he=c(re,2);{var ue=a=>{var t=Ke(),s=o(t);O(s,{get content(){return V()},padded:!1}),r(a,t)};i(he,a=>{V()&&a(ue)})}r(le,Z),ke()}export{Ve as default};
