.json-viewer.svelte-z13g04{font-family:var(--font-mono, ui-monospace);font-size:.8125rem;padding:.75rem 1rem;background:var(--color-card-bg, #fcfaf7);color:var(--color-text, #1f1f1f);border:1px solid var(--color-border, #f0ebe4);border-radius:var(--radius-xl, 16px)}.json-viewer.dark.svelte-z13g04{background:#0f172a;color:#e2e8f0;border-color:#334155}.json-row.svelte-z13g04{display:flex;gap:.5rem;margin:.15rem 0}.json-key.svelte-z13g04{color:var(--color-primary-text, #1f6c68)}.json-viewer.dark.svelte-z13g04 .json-key:where(.svelte-z13g04){color:#93c5fd}.json-sep.svelte-z13g04{color:var(--color-muted-light, #8a847c)}.json-children.svelte-z13g04{margin-left:1rem;border-left:1px dashed var(--color-border, #f0ebe4);padding-left:.75rem}.json-viewer.dark.svelte-z13g04 .json-children:where(.svelte-z13g04){border-left-color:#334155}.json-primitive.svelte-z13g04{color:var(--color-text, #1f1f1f)}.json-viewer.dark.svelte-z13g04 .json-primitive:where(.svelte-z13g04){color:#e2e8f0}summary.svelte-z13g04{cursor:pointer;color:var(--color-muted, #6b665f)}.json-viewer.dark.svelte-z13g04 summary:where(.svelte-z13g04){color:#94a3b8}
